.. image:: https://github.com/utkarsh0702/vedicpy/blob/master/logo.png
   :height: 300px
   :width: 500 px

.. image:: https://img.shields.io/pypi/v/vedicpy.svg
        :target: https://pypi.python.org/pypi/vedicpy
        :alt: pypi


.. image:: https://readthedocs.org/projects/vedic/badge/?version=latest
        :target: https://vedic.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://img.shields.io/pypi/pyversions/vedicpy.svg
        :target: https://pypi.python.org/pypi/vedicpy
        :alt: Python Versions

.. image:: https://img.shields.io/github/license/utkarsh0702/vedicpy.svg
        :target: https://github.com/utkarsh0702/vedicpy/blob/master/LICENSE
        :alt: License

A Python Package for Vedic Mathematics

- **Documentation:** https://vedic.readthedocs.io/en/latest/?badge=latest
- **Source Code:** https://github.com/utkarsh0702/vedicpy



**How to use it**
-----------------

**1. Installation**

.. code:: rst

    pip install vedicpy

**2. Usage**

::

    import vedicpy as vedic
    print(vedic.cube_cuberoot.cube_2digit_number(43))

**Directory Structure**
-----------------------

.. code:: rst

    │─── tests
    |     │── __init__.py
    |     └── test_module.py
    │─── vedicpy
    |     │── __init__.py
    |     │── compliment.py
    |     │── cube_cuberoot.py
    |     │── divisibility.py
    |     │── division.py
    |     │── multiply.py
    |     │── recurring.py
    |     └── sq_sqrt.py
    │─── .gitignore
    │─── AUTHORS.rst 
    │─── CONTRIBUTING.rst 
    │─── HISTORY.rst 
    │─── LICENSE
    │─── MANIFEST.in
    │─── README.rst
    │─── setup.cfg
    └─── setup.py
